import { StateContext, Destination, TransactionContext } from './destination-kit';
import type { DestinationDefinition, StatsContext, Logger, EngageDestinationCache, RequestFn, SubscriptionMetadata } from './destination-kit';
import type { JSONObject } from './json-object';
import type { SegmentEvent } from './segment-event';
import { AuthTokens } from './destination-kit/parse-settings';
import { Features } from './mapping-kit';
import { ExecuteDynamicFieldInput } from './destination-kit/action';
import { DynamicFieldResponse, Result } from './destination-kit/types';
interface InputData<Settings> {
    event?: Partial<SegmentEvent>;
    mapping?: JSONObject;
    settings?: Settings;
    useDefaultMappings?: boolean;
    auth?: AuthTokens;
    features?: Features;
    statsContext?: StatsContext;
    logger?: Logger;
    engageDestinationCache?: EngageDestinationCache;
    transactionContext?: TransactionContext;
    stateContext?: StateContext;
    subscriptionMetadata?: SubscriptionMetadata;
}
declare class TestDestination<T, AudienceSettings = any> extends Destination<T, AudienceSettings> {
    responses: Destination['responses'];
    results: Result[];
    constructor(destination: DestinationDefinition<T>);
    testDynamicField(action: string, fieldKey: string, data: ExecuteDynamicFieldInput<T, object>, dynamicFn?: RequestFn<any, any, DynamicFieldResponse, AudienceSettings>): Promise<never[] | DynamicFieldResponse>;
    testAction(action: string, { event, mapping, settings, useDefaultMappings, auth, features, statsContext, logger, engageDestinationCache, transactionContext, stateContext, subscriptionMetadata }: InputData<T>): Promise<Destination['responses']>;
    testBatchAction(action: string, { events, mapping, settings, useDefaultMappings, auth, features, statsContext, logger, engageDestinationCache, transactionContext, stateContext, subscriptionMetadata }: Omit<InputData<T>, 'event'> & {
        events?: SegmentEvent[];
    }): Promise<Destination['responses']>;
}
export declare function createTestIntegration<T>(destination: DestinationDefinition<T>): TestDestination<T>;
export {};
